==> php3_3.0.5.orig.tar.gz: php3-3.0.5/functions/php3_snmp.h <==
/*
   +----------------------------------------------------------------------+
   | PHP HTML Embedded Scripting Language Version 3.0                     |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997,1998 PHP Development Team (See Credits file)      |
   +----------------------------------------------------------------------+
   | This program is free software; you can redistribute it and/or modify |
   | it under the terms of one of the following licenses:                 |
   |                                                                      |
   |  A) the GNU General Public License as published by the Free Software |
   |     Foundation; either version 2 of the License, or (at your option) |
   |     any later version.                                               |
   |                                                                      |
   |  B) the PHP License as published by the PHP Development Team and     |
   |     included in the distribution in the file: LICENSE                |
   |                                                                      |
   | This program is distributed in the hope that it will be useful,      |
   | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
   | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
   | GNU General Public License for more details.                         |
   |                                                                      |
   | You should have received a copy of both licenses referred to here.   |
   | If you did not, or have any questions about PHP licensing, please    |
   | contact core@php.net.                                                |
   +----------------------------------------------------------------------+
   | Authors: Rasmus Lerdorf <rasmus@lerdorf.on.ca>                       |
   +----------------------------------------------------------------------+
 */
/* $Id: php3_snmp.h,v 1.2 1998/09/19 14:21:24 rasmus Exp $ */
#ifndef _PHP3_SNMP_H
#define _PHP3_SNMP_H

#if COMPILE_DL
#undef HAVE_SNMP
#define HAVE_SNMP 1
#endif
#if HAVE_SNMP
#ifndef DLEXPORT
#define DLEXPORT
#endif

extern php3_module_entry snmp_module_entry;
#define snmp_module_ptr &snmp_module_entry

extern int php3i_snmp_init(INIT_FUNC_ARGS);
extern void php3_snmpget(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_snmpwalk(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_info_snmp(void);
#else

#define snmp_module_ptr NULL

#endif /* HAVE_SNMP */

#endif  /* _PHP3_SNMP_H */

==> php3_3.0.18.orig.tar.gz: php3-3.0.18/functions/php3_snmp.h <==
/*
   +----------------------------------------------------------------------+
   | PHP HTML Embedded Scripting Language Version 3.0                     |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2000 PHP Development Team (See Credits file)      |
   +----------------------------------------------------------------------+
   | This program is free software; you can redistribute it and/or modify |
   | it under the terms of one of the following licenses:                 |
   |                                                                      |
   |  A) the GNU General Public License as published by the Free Software |
   |     Foundation; either version 2 of the License, or (at your option) |
   |     any later version.                                               |
   |                                                                      |
   |  B) the PHP License as published by the PHP Development Team and     |
   |     included in the distribution in the file: LICENSE                |
   |                                                                      |
   | This program is distributed in the hope that it will be useful,      |
   | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
   | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
   | GNU General Public License for more details.                         |
   |                                                                      |
   | You should have received a copy of both licenses referred to here.   |
   | If you did not, or have any questions about PHP licensing, please    |
   | contact core@php.net.                                                |
   +----------------------------------------------------------------------+
   | Authors: Rasmus Lerdorf <rasmus@lerdorf.on.ca>                       |
   |          Mike Jackson <mhjack@tscnet.com>                            |
   |          Steven Lawrance <slawrance@technologist.com>                |
   +----------------------------------------------------------------------+
 */
/* $Id: php3_snmp.h,v 1.7 2000/01/01 04:44:09 sas Exp $ */
#ifndef _PHP3_SNMP_H
#define _PHP3_SNMP_H

#if COMPILE_DL
#undef HAVE_SNMP
#define HAVE_SNMP 1
#endif
#if HAVE_SNMP
#ifndef DLEXPORT
#define DLEXPORT
#endif

extern php3_module_entry snmp_module_entry;
#define snmp_module_ptr &snmp_module_entry

extern int php3i_snmp_init(INIT_FUNC_ARGS);
extern PHP_FUNCTION(snmpget);
extern PHP_FUNCTION(snmpwalk);
extern PHP_FUNCTION(snmprealwalk);
extern PHP_FUNCTION(snmpwalkoid);
extern PHP_FUNCTION(snmp_get_quick_print);
extern PHP_FUNCTION(snmp_set_quick_print);
extern PHP_FUNCTION(snmpset);
extern void php3_info_snmp(void);
#else

#define snmp_module_ptr NULL

#endif /* HAVE_SNMP */

#endif  /* _PHP3_SNMP_H */
